pub struct DbTransactionMiddleware { /* private fields */ }Available on crate feature
sea-orm only.Expand description
A middleware for automatically creating and managing
sea_orm::DatabaseTransactions for incoming
requests.
Implementations
Sourceimpl DbTransactionMiddleware
impl DbTransactionMiddleware
Sourcepub fn new(db: DatabaseConnection) -> Self
pub fn new(db: DatabaseConnection) -> Self
Create a new DbTransactionMiddleware.
Sourcepub fn with_check_fn<F>(self, check_fn: F) -> Self
pub fn with_check_fn<F>(self, check_fn: F) -> Self
Use a custom function to check if a response is successful.
By default a response is considered successful iff it is neither a client error (400-499) nor a server error (500-599).
Example
use poem::{EndpointExt, Route};
use poem_ext::db::DbTransactionMiddleware;
let app = Route::new().nest("/", api_service).with(
// commit only if the response status is "200 OK", otherwise rollback the transaction
DbTransactionMiddleware::new(db_connection).with_check_fn(|response| response.is_ok()),
);Trait Implementations
Sourceimpl Debug for DbTransactionMiddleware
impl Debug for DbTransactionMiddleware
Sourceimpl<E: Endpoint> Middleware<E> for DbTransactionMiddleware
impl<E: Endpoint> Middleware<E> for DbTransactionMiddleware
Sourcefn combine<T>(self, other: T) -> CombineMiddleware<Self, T, E>
fn combine<T>(self, other: T) -> CombineMiddleware<Self, T, E>
Create a new middleware by combining two middlewares. Read more
Sourcefn combine_if<T>(
self,
enable: bool,
other: T,
) -> EitherMiddleware<Self, CombineMiddleware<Self, T, E>, E>
fn combine_if<T>( self, enable: bool, other: T, ) -> EitherMiddleware<Self, CombineMiddleware<Self, T, E>, E>